html, body {
    margin: 0;
    background: #EFEFEF;
    font-family: sans-serif !important; /*override font from perl.css stylesheet, until we can get rid of it*/
}

html {
    padding: 0;
    width: 100%;
    position: relative;
    min-height: 100%;
}

body {
    padding: 0 2em;
    width: auto;
    margin-bottom: 5.5em;  /* max footer height */
}

.title {
    margin-top: 0;
    text-align: center;
}
.subtitle {
    text-align: center;
    font-style: italic;
}

pre {
    background-color: #DFDFDF;
    border: 1px solid #CFCFCF;
    padding: 0.6ex;
    color: black;
    overflow: auto;
    white-space: pre-wrap;
    word-break: break-all;
}

code {
    color: #666;
}

pre a, pre a:visited, pre a:link {
    text-decoration: underline;
    color: black;
}

pre a:hover, pre a:link:hover {
    text-decoration: none;
    color: inherit;
}

img, svg {
    max-width: 100%;
}

tr:nth-child(odd) {
    background-color: #F5EF7B;
}
tr:nth-child(even) {
    background-color: none;
}

td {
    padding: 0.4em;
}
td p {
    margin: 0;
}

.pretty-box {
    border: 0.2em solid;
    background-style: solid;
    border-radius: 1em;
    box-shadow: 0.5em 0.5em 1em #888888;
    padding: 2em;
}

.red {
    border-color: #E43B59;
    background-color: #E47286;
}

.green {
    border-color: #8BC313;
    background-color: #C0E472;
}

.dark-green {
    border-color: #8BC313;
    background-color: #A0CE3D;
}

.darker-green {
    border-color: #8BC313;
    background-color: #8BC313;
}

.blue {
    border-color: #63A4FF;
    background-color: #80B5FF;
}

.yellow {
    border-color: #F2C100;
    background-color: #F5EF7B;
}

#header {
    font-family: sans-serif;
    font-weight: bold;
    border-radius: 0 0 4em 4em;
    margin: -2em auto 0; /*extra top padding and negative margin preserves bleed-off illusion for shadow*/
    padding: 3em 0em 0em 0em;
    line-height: 2em;
    overflow: hidden;
    border-top: none;
}

#header > a {
    color: #000000;
    text-decoration: none;
    font-size: 2em;
    margin-left: 1.5em;
}

@media (max-width : 560px) {
    #header > a {
        font-size: 1.1em;
        display: block;
        padding: 5px 10px 0;
        margin: 0;
        text-align: center;
    }
    #home_logo {
        display: none;
    }
}


#logo {
    display: inline-block;
    margin: -0.75em 0 -0.5em -0.5em;
    border: none;
    vertical-align: middle;
}

#search.not-found > div:before {
    content: "Sorry, no results were found";
    background: red;
    color: white;
    padding: 2px 15px;
    border-radius: 3px;
    position: absolute;
    bottom: -4ex;
    left: 0;
}

#search {
    position: relative;
    float: right;
    margin-right: 1.5em;
    margin-bottom: 0.5em;
    width: 32%;
    min-width: 9em;
    max-width: 35em;
}

#search.two-row {
    width: 84%;
    margin-top: 10px;
}

#search label {
    float: left;
    font-size: 1.25em;
}

#search div {
    overflow: hidden;
    border-width: 0.1em;
    border-style: solid;
    border-radius: 0.5em;
    padding: 0 0.5em;
    background-color: #FFFFFF;
}

#query {
    outline: none;
    border: none;
    margin: 0;
    padding: 0;
    width: 100%;
    background: none;
    color: #777777;
}

#query:focus {
    color: #000000;
}

.ui-autocomplete-category {
    font-weight: bold;
    font-style: italic;
    background-color: #DAFE8C;
    padding: 2px 5px;
    line-height: 1.5;
}

.menu {
    border: none;
    text-align: center;
    display: block;
    font-weight: normal;
}

.menu-items {
    display: inline-block;
    margin-right: auto;
    margin-left: auto;
    margin-bottom: -0.1em;
    width: 100%;
    height: 2.6em;
    line-height: 1.8em;
}

.menu-item {
    display: inline-block;
    padding-right: 1.0em;
    font-size: 1.1em;
    margin: 0.4em 0;
}

.menu-item+.menu-item {
    border-left: 2px ridge rgba(192,228,114,0.6);  /* #C0E472 */
    padding-left: 1.1em;
}
.menu-item.selected+.menu-item {
    border-left: none;
}

.menu-item.selected {
    border-radius: 1em 1em 0 0;
    box-shadow: 0.5em 0.5em 1em #888888;
    display: inline-block;
    border-left: none;
    border-bottom: solid inherit;
    color: black;
    text-decoration: none;
    padding-left:  0.9em;
    padding-right: 0.9em;
    margin-top: 0.3em;
    line-height: 2.1em;
}

#formalities { font-style: italic; }

#content-wrapper { padding-bottom: 2em; }

#content {
    margin: 2em auto;
    overflow: hidden;
    max-width: 800px;
    background: #FFFFFF;
    background-image: url(/images/camelia-faded.png);
    background-repeat: no-repeat;
    background-position: right 2em top 2em;
}

#content dt {
    font-weight: bold;
    margin-bottom: 0.2em;
}

#content dd {
    margin-bottom: 1em;
}

#content hr {
    border: none;
    margin: 0 3em;
    padding: 0;
    height: 20px;
    background-color: transparent;
    background-image: radial-gradient(#F5EF7B 30%, transparent 30%);
    background-size: 25px 25px;
    background-repeat: round no-repeat;
    background-position: 0 center;
}

#content p:nth-child(2) {
    margin-top: 0;
    padding-top: 0;
}

#footer-wrapper {
    position: absolute;
    bottom: 0;
    width: 100%;
    margin: 0 -2em;
    padding-bottom: 2em;
    overflow: hidden;
    max-height: 5.5em;  /* max footer height */
}

#footer {
    margin: 0 2em;
    padding: 0 1em;
}

